==> xoops-2.4.5.tbz: www/xoops/htdocs/language/english/formdhtmltextarea.php <==
<?php
/**
 * Language definitions for {@link XoopsFormDhtmlTextArea}
 *
 * You may not change or alter any portion of this comment or credits
 * of supporting developers from this source code or any supporting source code 
 * which is considered copyrighted (c) material of the original comment or credit authors.
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * @copyright       The XOOPS Project http://sourceforge.net/projects/xoops/
 * @license         http://www.fsf.org/copyleft/gpl.html GNU public license
 * @package         kernel
 * @subpackage      form
 * @since           2.3.0
 * @author          Taiwen Jiang <phppp@users.sourceforge.net>
 * @version         $Id: formdhtmltextarea.php 3318 2009-07-04 13:28:33Z trabis $
 */
defined('XOOPS_ROOT_PATH') or die('Restricted access');

// _LANGCODE: en
// _CHARSET : UTF-8
// Translator: XOOPS Translation Team
/**
 * Localized fonts 
 */
$GLOBALS['formtextdhtml_fonts'] = array(
    'Arial' , 
    'Courier' , 
    'Georgia' , 
    'Helvetica' , 
    'Impact' , 
    'Verdana' , 
    'Haettenschweiler');
/**
 * Localized font sizes: 'font size value' => 'font size name'
 */
$GLOBALS['formtextdhtml_sizes'] = array(
    'xx-small' => 'xx-Small' , 
    'x-small' => 'x-Small' , 
    'small' => 'Small' , 
    'medium' => 'Medium' , 
    'large' => 'Large' , 
    'x-large' => 'x-Large' , 
    'xx-large' => 'xx-Large');
define('_XOOPS_FORM_ALT_URL', 'URL');
define('_XOOPS_FORM_ALT_EMAIL', 'Email');
define('_XOOPS_FORM_ALT_IMG', 'Images');
define('_XOOPS_FORM_ALT_IMAGE', 'Inside images');
define('_XOOPS_FORM_ALT_SMILEY', 'Smiley');
define('_XOOPS_FORM_ALT_CODE', 'Source code');
define('_XOOPS_FORM_ALT_QUOTE', 'Quote');
define('_XOOPS_FORM_ALT_BOLD', 'Bold');
define('_XOOPS_FORM_ALT_ITALIC', 'Italic');
define('_XOOPS_FORM_ALT_UNDERLINE', 'Underline');
define('_XOOPS_FORM_ALT_LINETHROUGH', 'Linethrough');
define('_XOOPS_FORM_ALT_ENTERHEIGHT', 'Height:');
define('_XOOPS_FORM_ALT_ENTERWIDTH', 'width:');
define('_XOOPS_FORM_ALT_LEFT', 'Left');
define('_XOOPS_FORM_ALT_RIGHT', 'Right');
define('_XOOPS_FORM_ALT_CENTER', 'Center');
define('_XOOPS_FORM_ALTFLASH', 'Flash');
define('_XOOPS_FORM_ALTMMS', 'MMS');
define('_XOOPS_FORM_ALTRTSP', 'Real Player');
define('_XOOPS_FORM_ALTIFRAME', 'IFRAME');
define('_XOOPS_FORM_ALTWIKI', 'WIKI link');
define('_XOOPS_FORM_ENTERIFRAMEURL', 'IFRAME URL:');
define('_XOOPS_FORM_ENTERMMSURL', 'RMMS URL:');
define('_XOOPS_FORM_ENTERWMPURL', 'WMP URL:');
define('_XOOPS_FORM_ENTERFLASHURL', 'FLASH URL:');
define('_XOOPS_FORM_ENTERYOUTUBEURL', 'Youtube URL:');
define('_XOOPS_FORM_ENTERRTSPURL', 'RTSP URL:');
define('_XOOPS_FORM_ENTERWIKITERM', 'The word to be linked to Wiki:');
define('_XOOPS_FORM_ALTMP3', 'MP3');
define('_XOOPS_FORM_ENTERMP3URL', 'MP3 URL');
define('_XOOPS_FORM_ALT_CHECKLENGTH', 'Check text length');
define('_XOOPS_FORM_ALT_LENGTH', 'Current content length: %s');
define('_XOOPS_FORM_ALT_LENGTH_MAX', 'Maximum length: ');
define('_XOOPS_FORM_PREVIEW_CONTENT', 'Click the <strong>' . _PREVIEW . '</strong> to see the content in action.');

define('_XOOPS_FORM_ALTYOUTUBE', 'Youtube');
?>

==> xoops-2.5.5.tbz: www/xoops/htdocs/language/english/formdhtmltextarea.php <==
<?php
/**
 * Language definitions for {@link XoopsFormDhtmlTextArea}
 *
 * You may not change or alter any portion of this comment or credits
 * of supporting developers from this source code or any supporting source code 
 * which is considered copyrighted (c) material of the original comment or credit authors.
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * @copyright       The XOOPS Project http://sourceforge.net/projects/xoops/
 * @license         GNU GPL 2 (http://www.gnu.org/licenses/old-licenses/gpl-2.0.html)
 * @package         kernel
 * @subpackage      form
 * @since           2.3.0
 * @author          Taiwen Jiang <phppp@users.sourceforge.net>
 * @version         $Id: formdhtmltextarea.php 8066 2011-11-06 05:09:33Z beckmi $
 */
defined('XOOPS_ROOT_PATH') or die('Restricted access');

// _LANGCODE: en
// _CHARSET : UTF-8
// Translator: XOOPS Translation Team
/**
 * Localized fonts 
 */
$GLOBALS['formtextdhtml_fonts'] = array(
    'Arial' , 
    'Courier' , 
    'Georgia' , 
    'Helvetica' , 
    'Impact' , 
    'Verdana' , 
    'Haettenschweiler');
/**
 * Localized font sizes: 'font size value' => 'font size name'
 */
$GLOBALS['formtextdhtml_sizes'] = array(
    'xx-small' => 'xx-Small' , 
    'x-small' => 'x-Small' , 
    'small' => 'Small' , 
    'medium' => 'Medium' , 
    'large' => 'Large' , 
    'x-large' => 'x-Large' , 
    'xx-large' => 'xx-Large');
define('_XOOPS_FORM_ALT_URL', 'URL');
define('_XOOPS_FORM_ALT_EMAIL', 'Email');
define('_XOOPS_FORM_ALT_IMG', 'Images');
define('_XOOPS_FORM_ALT_IMAGE', 'Inside images');
define('_XOOPS_FORM_ALT_SMILEY', 'Smiley');
define('_XOOPS_FORM_ALT_CODE', 'Source code');
define('_XOOPS_FORM_ALT_QUOTE', 'Quote');
define('_XOOPS_FORM_ALT_BOLD', 'Bold');
define('_XOOPS_FORM_ALT_ITALIC', 'Italic');
define('_XOOPS_FORM_ALT_UNDERLINE', 'Underline');
define('_XOOPS_FORM_ALT_LINETHROUGH', 'Linethrough');
define('_XOOPS_FORM_ALT_ENTERHEIGHT', 'Height:');
define('_XOOPS_FORM_ALT_ENTERWIDTH', 'Width:');
define('_XOOPS_FORM_ALT_LEFT', 'Left');
define('_XOOPS_FORM_ALT_RIGHT', 'Right');
define('_XOOPS_FORM_ALT_CENTER', 'Center');
define('_XOOPS_FORM_ALTFLASH', 'Flash');
define('_XOOPS_FORM_ALTMMS', 'MMS');
define('_XOOPS_FORM_ALTRTSP', 'Real Player');
define('_XOOPS_FORM_ALTIFRAME', 'IFRAME');
define('_XOOPS_FORM_ALTWIKI', 'WIKI link');
define('_XOOPS_FORM_ENTERIFRAMEURL', 'IFRAME URL:');
define('_XOOPS_FORM_ENTERMMSURL', 'RMMS URL:');
define('_XOOPS_FORM_ENTERWMPURL', 'WMP URL:');
define('_XOOPS_FORM_ENTERFLASHURL', 'FLASH URL:');
define('_XOOPS_FORM_ENTERYOUTUBEURL', 'Youtube URL:');
define('_XOOPS_FORM_ENTERRTSPURL', 'RTSP URL:');
define('_XOOPS_FORM_ENTERWIKITERM', 'The word to be linked to Wiki:');
define('_XOOPS_FORM_ALTMP3', 'MP3');
define('_XOOPS_FORM_ENTERMP3URL', 'MP3 URL');
define('_XOOPS_FORM_ALT_CHECKLENGTH', 'Check text length');
define('_XOOPS_FORM_ALT_LENGTH', 'Current content length: %s');
define('_XOOPS_FORM_ALT_LENGTH_MAX', 'Maximum length: ');
define('_XOOPS_FORM_PREVIEW_CONTENT', 'Click the <strong>' . _PREVIEW . '</strong> to see the content in action.');

define('_XOOPS_FORM_ALTYOUTUBE', 'Youtube');
?>
